==> org-lsst-ccs-buses-definition-5.4.0-sources.jar: org/lsst/ccs/bus/messages/StatusStateChangeNotification.java <==
package org.lsst.ccs.bus.messages;


import org.lsst.ccs.bus.states.StateBundle;
import org.lsst.ccs.utilities.taitime.CCSTimeStamp;

/**
 * A StatusChangeNotification for State changes.
 * This is an event driven message sent on the Status bus when a State change
 * occurs. It contains the new (current) state of the subsystem and the old one.
 * 
 * @author The LSST CCS Team
 */
public final class StatusStateChangeNotification extends StatusMessage<StateBundle,Object> {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 7295728245721L;
    
    private final CCSTimeStamp stateTransitionTimestamp;
    
    /**
     * Create a StatusStateChangeNotification object.
     * 
     * @param stateTransitionTimestamp The CCSTimeStamp corresponding to this state transition
     * @param oldState The old state before the State change
     */
    public StatusStateChangeNotification(CCSTimeStamp stateTransitionTimestamp, StateBundle oldState) {
        super(oldState);
        this.stateTransitionTimestamp = stateTransitionTimestamp;
    }


    /**
     * Get the new state of the Agent.
     * @return The new state of the Agent.
     */
    public StateBundle getNewState() {
        return getState();
    }

    /**
     * Get the old state of the Agent.
     * @return The old state of the Agent.
     */
    public StateBundle getOldState() {
        return getObject();
    }
    
    @Override
    protected Object encodeObject(StateBundle obj) {
        return null;
    }
    
    /**
     * Get the CCSTimeStamp of this state transition.
     *
     * @return The CCSTimeStamp when the state transition occurred.
     */
    public CCSTimeStamp getStateTransitionTimestamp() {
        return stateTransitionTimestamp != null ? stateTransitionTimestamp : getCCSTimeStamp();
    }
    
}

==> org-lsst-ccs-buses-definition-6.2.3-20250207.052548-1-sources.jar: org/lsst/ccs/bus/messages/StatusStateChangeNotification.java <==
package org.lsst.ccs.bus.messages;


import org.lsst.ccs.bus.states.StateBundle;
import org.lsst.ccs.utilities.taitime.CCSTimeStamp;

/**
 * A StatusChangeNotification for State changes.
 * This is an event driven message sent on the Status bus when a State change
 * occurs. It contains the new (current) state of the subsystem and the old one.
 * 
 * @author The LSST CCS Team
 */
public final class StatusStateChangeNotification extends StatusMessage<StateBundle,Object> {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 7295728245721L;
    
    private final CCSTimeStamp stateTransitionTimestamp;
    private final String cause;
    
    /**
     * Create a StatusStateChangeNotification object.
     * 
     * @param cause The reason the state transition happened.
     * @param stateTransitionTimestamp The CCSTimeStamp corresponding to this state transition
     * @param oldState The old state before the State change
     */
    public StatusStateChangeNotification(CCSTimeStamp stateTransitionTimestamp, StateBundle oldState, String cause) {
        this(stateTransitionTimestamp, oldState, cause, false);
    }

    /**
     * Create a StatusStateChangeNotification object.
     * 
     * @param cause The reason the state transition happened.
     * @param stateTransitionTimestamp The CCSTimeStamp corresponding to this state transition
     * @param oldState The old state before the State change
     * @param skipSerialization do not serialize the object. This is to be true only
     *                          for messages that are created on the client side during
     *                          the preProcessBusMessage step.
     */
    public StatusStateChangeNotification(CCSTimeStamp stateTransitionTimestamp, StateBundle oldState, String cause, boolean skipSerialization) {
        super(oldState, skipSerialization);
        this.stateTransitionTimestamp = stateTransitionTimestamp;
        this.cause = cause;
    }

    /**
     * Get the new state of the Agent.
     * @return The new state of the Agent.
     */
    public StateBundle getNewState() {
        return getState();
    }

    /**
     * Get the old state of the Agent.
     * @return The old state of the Agent.
     */
    public StateBundle getOldState() {
        return getObject();
    }
    
    @Override
    protected Object encodeObject(StateBundle obj) {
        return null;
    }
    
    /**
     * Get the CCSTimeStamp of this state transition.
     *
     * @return The CCSTimeStamp when the state transition occurred.
     */
    public CCSTimeStamp getStateTransitionTimestamp() {
        return stateTransitionTimestamp != null ? stateTransitionTimestamp : getCCSTimeStamp();
    }
    
    /**
     * Get the reason for this state transition.
     * 
     * @return The reason for this state transition. Null if no reason was provided.
     */
    public String getCause() {
        return cause;
    }
}
